@@ -18,6 +18,7 @@ from .yamlconfig import parse_yaml_conf
 from .graphdb    import GraphDBClient
 from .fuseki     import FusekiClient
 from .rdf4j      import RFD4JClient
+from .qlever     import QleverClient
 # from .oxigraph   import OxigraphClient  # in preparation
 # from .virtuoso   import VirtuosoClient  # in preparation
 from .fileserver import LocalFileServer
@@ -282,6 +283,10 @@ INSERT {{
             void:triples               ?c   ;
             dct:modified               ?now ;
             ex:has_sha256              "{sha256}" .
+            
+            kgsteward:triples 
+            kgsteward:modified
+            kgsteward:checksum
     }}
 }}
 WHERE {{
@@ -363,6 +368,15 @@ def main():
             )
         except Exception as e:
             stop_error( "Failed to connect to Fuseki server: " + str( e ))
+    elif config["server"]["brand"] == "qlever":
+        try:
+            server = QleverClient(
+                replace_env_var( config["server"]["location"] ),
+                replace_env_var( config["server"]["repository"] ),
+                echo = args.v
+            )
+        except Exception as e:
+            stop_error( "Failed to connect to Qlever server: " + str( e ))
     else:
         stop_error( "Unknown server brand: " + config["server"]["brand"] )
 
@@ -626,11 +640,18 @@ INSERT DATA {{
                     if args.v:
                         print_strip( sparql, color = "green" )
                     r = server.sparql_query( sparql, echo = args.v, timeout=args.timeout )
-                    if args.timeout is not None and r is None: # likely timeout
-                        # report( "Result", "Unknown" )
-                        test_to = test_to + 1
+                    if r is None:
+                        if args.timeout is not None: # likely timeout
+                            test_to = test_to + 1
+                        else:
+                            test_ko = test_ko + 1
+                        continue
+                    try:
+                        header, rows = sparql_result_to_table( r )
+                    except Exception as e :
+                        print_warn( str( e ))
+                        test_ko = test_ko + 1
                         continue
-                    header, rows = sparql_result_to_table( r )
                     ok = True
                     if "min_row_count" in record["test"]:
                         if len( rows ) < record["test"]["min_row_count"] :
@@ -654,7 +675,7 @@ INSERT DATA {{
         report( "test timeout", test_to )
         report( "test passed",  test_ok )
         report( "test failed",  test_ko )
-        sys.exit( test_ko == 0 )
+        sys.exit( 0 if test_ko == 0 else 1 )
 
     # --------------------------------------------------------- #
     # Refresh all GraphDB preloaded queries
@@ -715,78 +736,78 @@ INSERT DATA {{
                             'json'    : { 'name': name, 'body': sparql, "shared": "true" }
                         }, [ 201 ] )
 
-    if args.sib_swiss_editor:
-        print_break()
-        print_task( "Prepare queries for SIB-swiss editor" )     
-        counter = 0 # to keep track of the original input order 
-        prefix = {} # to create a non-redundant list
-        catch_key_value_ttl = re.compile( r"@prefix\s+(\S*):\s+<([^>]+)>", re.IGNORECASE )
-        catch_key_value_rq  = re.compile( r"PREFIX\s+(\S*):\s+<([^>]+)>",  re.IGNORECASE )
-        g = Graph()
-        SPARQLQUERY   = Namespace( server.get_endpoint_query() + "/.well-known/sparql-examples/" )
-        prefixes_iri  = URIRef(    server.get_endpoint_query() + "/.well-known/prefixes" )
-        PREFIX        = Namespace( server.get_endpoint_query() + "/.well-known/prefix/" )
-        RDF           = Namespace( "http://www.w3.org/1999/02/22-rdf-syntax-ns#" )
-        RDFS          = Namespace( "http://www.w3.org/2000/01/rdf-schema#" )
-        SCHEMA        = Namespace( "https://schema.org/" )
-        SH            = Namespace( "http://www.w3.org/ns/shacl#" )
-        SPEX          = Namespace( "https://purl.expasy.org/sparql-examples/ontology#" )
-        XSD           = Namespace( "http://www.w3.org/2001/XMLSchema#" )
-        OWL           = Namespace( "http://www.w3.org/2002/07/owl#" )
-        g.bind( "rdf",    RDF )
-        g.bind( "rdfs",   RDFS )
-        g.bind( "rdfs",   RDFS )
-        g.bind( "schema", SCHEMA )
-        g.bind( "sh",     SH )
-        g.bind( "spex",   SPEX )
-        g.bind( "xsd",    XSD )
-        g.bind( "owl",    OWL )
-        g.bind( "sparql_query_" + config["server"]["repository"], SPARQLQUERY )
-        g.bind( "prefix_" + config["server"]["repository"],    PREFIX )
-        if "queries" in config:
-            for record in config["queries"] :
-                for filename in record["file"]:
-                    report( "read", filename )
-                    report( "parse file", filename )
-                    counter = counter + 1
-                    comment = []
-                    select  = [] # i.e. the SPARQL query itself
-                    name    = re.sub( r'(.*/|)([^/]+)\.\w+$', r'\2', filename )
-                    with open( filename ) as file:
-                        for line in file:
-                            if re.match( "^#", line ):
-                                comment.append( re.sub( r"^#\s*", "", line.rstrip() ))
-                            else:
-                                select.append( line.rstrip().replace( "\t", "    "))
-                                match = catch_key_value_rq.search( line )
-                                if match:
-                                    prefix[match.group( 1 )] = match.group( 2 )
-                    # server.validate_sparql_query( "\n".join( select ), echo=args.v, timeout=args.timeout )
-                    iri = SPARQLQUERY[ "query_" + config["server"]["repository"] + str( counter ).rjust( 4, '0' )]
-                    g.add(( iri, RDF.type, SH.SPARQLExecutable ))
-                    g.add(( iri, RDF.type, SH.SPARQLSelectExecutable ))
-                    # g.add(( iri, RDFS.label,    Literal( "<b>" + name.replace( "_", " ") + "</b><br>")))
-                    g.add(( iri, RDFS.comment,  Literal( "<b>" + name.replace( "_", " ") + "</b><br>") + "\n".join( comment )))
-                    g.add(( iri, SH.prefixes,   prefixes_iri ))
-                    g.add(( iri, SH.select,     Literal( "\n".join( select ))))
-                    # g.add(( iri, SCHEMA.target, URIRef( server.get_endpoint_query()))) not portable
-        if "prefixes" in config:
-            for filename in config["prefixes"] :
-                report( "parse file", filename )
-                file = open( replace_env_var( filename ))
-                for line in file:
-                    match = catch_key_value_ttl.search( line )
-                    if match:
-                        prefix[ match.group( 1 ) ] = match.group( 2 )
-        for key in prefix:
-            g.add(( prefixes_iri,  SH.declare,   PREFIX[ key ]))
-            g.add(( PREFIX[ key ], SH.prefix,    Literal( key )))
-            g.add(( PREFIX[ key ], SH.namespace, Literal( prefix[key], datatype=XSD.anyURI )))
-        g.serialize(
-            format="turtle",
-            destination = args.sib_swiss_editor
-        )
-        sys.exit( 0 )
+    # if args.sib_swiss_editor:
+    #     print_break()
+    #     print_task( "Prepare queries for SIB-swiss editor" )     
+    #     counter = 0 # to keep track of the original input order 
+    #     prefix = {} # to create a non-redundant list
+    #     catch_key_value_ttl = re.compile( r"@prefix\s+(\S*):\s+<([^>]+)>", re.IGNORECASE )
+    #     catch_key_value_rq  = re.compile( r"PREFIX\s+(\S*):\s+<([^>]+)>",  re.IGNORECASE )
+    #     g = Graph()
+    #     SPARQLQUERY   = Namespace( server.get_endpoint_query() + "/.well-known/sparql-examples/" )
+    #     prefixes_iri  = URIRef(    server.get_endpoint_query() + "/.well-known/prefixes" )
+    #     PREFIX        = Namespace( server.get_endpoint_query() + "/.well-known/prefix/" )
+    #     RDF           = Namespace( "http://www.w3.org/1999/02/22-rdf-syntax-ns#" )
+    #     RDFS          = Namespace( "http://www.w3.org/2000/01/rdf-schema#" )
+    #     SCHEMA        = Namespace( "https://schema.org/" )
+    #     SH            = Namespace( "http://www.w3.org/ns/shacl#" )
+    #     SPEX          = Namespace( "https://purl.expasy.org/sparql-examples/ontology#" )
+    #     XSD           = Namespace( "http://www.w3.org/2001/XMLSchema#" )
+    #     OWL           = Namespace( "http://www.w3.org/2002/07/owl#" )
+    #     g.bind( "rdf",    RDF )
+    #     g.bind( "rdfs",   RDFS )
+    #     g.bind( "rdfs",   RDFS )
+    #     g.bind( "schema", SCHEMA )
+    #     g.bind( "sh",     SH )
+    #     g.bind( "spex",   SPEX )
+    #     g.bind( "xsd",    XSD )
+    #     g.bind( "owl",    OWL )
+    #     g.bind( "sparql_query_" + config["server"]["repository"], SPARQLQUERY )
+    #     g.bind( "prefix_" + config["server"]["repository"],    PREFIX )
+    #     if "queries" in config:
+    #         for record in config["queries"] :
+    #             for filename in record["file"]:
+    #                 report( "read", filename )
+    #                 report( "parse file", filename )
+    #                 counter = counter + 1
+    #                 comment = []
+    #                 select  = [] # i.e. the SPARQL query itself
+    #                 name    = re.sub( r'(.*/|)([^/]+)\.\w+$', r'\2', filename )
+    #                 with open( filename ) as file:
+    #                     for line in file:
+    #                         if re.match( "^#", line ):
+    #                             comment.append( re.sub( r"^#\s*", "", line.rstrip() ))
+    #                         else:
+    #                             select.append( line.rstrip().replace( "\t", "    "))
+    #                             match = catch_key_value_rq.search( line )
+    #                             if match:
+    #                                 prefix[match.group( 1 )] = match.group( 2 )
+    #                 # server.validate_sparql_query( "\n".join( select ), echo=args.v, timeout=args.timeout )
+    #                 iri = SPARQLQUERY[ "query_" + config["server"]["repository"] + str( counter ).rjust( 4, '0' )]
+    #                 g.add(( iri, RDF.type, SH.SPARQLExecutable ))
+    #                 g.add(( iri, RDF.type, SH.SPARQLSelectExecutable ))
+    #                 # g.add(( iri, RDFS.label,    Literal( "<b>" + name.replace( "_", " ") + "</b><br>")))
+    #                 g.add(( iri, RDFS.comment,  Literal( "<b>" + name.replace( "_", " ") + "</b><br>") + "\n".join( comment )))
+    #                 g.add(( iri, SH.prefixes,   prefixes_iri ))
+    #                 g.add(( iri, SH.select,     Literal( "\n".join( select ))))
+    #                 # g.add(( iri, SCHEMA.target, URIRef( server.get_endpoint_query()))) not portable
+    #     if "prefixes" in config:
+    #         for filename in config["prefixes"] :
+    #             report( "parse file", filename )
+    #             file = open( replace_env_var( filename ))
+    #             for line in file:
+    #                 match = catch_key_value_ttl.search( line )
+    #                 if match:
+    #                     prefix[ match.group( 1 ) ] = match.group( 2 )
+    #     for key in prefix:
+    #         g.add(( prefixes_iri,  SH.declare,   PREFIX[ key ]))
+    #         g.add(( PREFIX[ key ], SH.prefix,    Literal( key )))
+    #         g.add(( PREFIX[ key ], SH.namespace, Literal( prefix[key], datatype=XSD.anyURI )))
+    #     g.serialize(
+    #         format="turtle",
+    #         destination = args.sib_swiss_editor
+    #     )
+    #     sys.exit( 0 )
         
     if args.x:
         print_break()
