@@ -1,6 +1,8 @@
 # https://stackoverflow.com/questions/58703926/how-do-i-generate-yaml-containing-local-tags-with-ruamel-yaml$
 # https://app.soos.io/research/packages/Python/-/pydantic-yaml-parser/
 
+# FIXME: does "file_server_port" still make sense ?
+
 import yaml
 import yaml_include
 from dumper        import dump
@@ -21,7 +23,7 @@ description = {
     `${}`, `${}` and `${}`.
     Especially useful is `${dataset.name}` that can be used in be used in `dataset.replace` clause to indicate the current "active" context/named graph.
 """,
-    "server_brand": """String identifying the server brand. One of 'graphdb', 'rdf4j', 'fuseki' """,
+    "server_brand": """String identifying the server brand. One of 'graphdb', 'rdf4j', 'fuseki', 'qlever' """,
     "location" :  """URL of the server. The SPARQL endpoint locations for queries, updates and stores are specific to a server brand.""" ,
     "repository": """The name of the 'repository' (GraphDB/RDF4J naming) or 'dataset' (fuseki) in the triplestore.""",
     "username":      """The name of a user with write-access rights in the triplestore.""",
@@ -118,6 +120,7 @@ In each file, lines starting with "#" are considered as the query documentation
 description["location_graphdb"] = description["location"] + " GraphDB has location 'http://localhost:7200' by default"
 description["location_fuseki"]  = description["location"] + " Fuseki has location 'http://localhost:3030' by default"
 description["location_rdf4j"]   = description["location"] + " RDF4J has location 'http://localhost:8080' by default"
+description["location_qlever"]  = description["location"] + " Qlever has location 'http://localhost:7019' by default (this is a read-only server)"
 
 def describe( term ):
     if term in description:
@@ -141,7 +144,7 @@ class GraphDBConf( BaseModel ):
     brand             : Literal[ "graphdb" ] = Field( title = "GraphDB brand", description = describe( "server_brand" ))
     location          : str = Field( title = "Server URL", description = describe( "location_graphdb" ))
     server_config     : str = Field( title = "Server config file", description = describe( "server_config" ))
-    file_server_port  : Optional[ int ] = Field( None, title = "file_server_port", description = describe( "file_server_port" ))
+    # file_server_port  : Optional[ int ] = Field( None, title = "file_server_port", description = describe( "file_server_port" ))
     username          : Optional[ str ] = Field( None, title = "Username", description = describe( "username" ))
     password          : Optional[ str ] = Field( None, title = "Password", description = describe( "password" ))
     prefixes          : Optional[ List[str]]  = Field( None, title = "GraphDB namespace", description = describe( "prefixes" ))
@@ -152,14 +155,22 @@ class FusekiConf( BaseModel ):
     brand             : Literal[ "fuseki" ] = Field( title = "Fuseki brand", description = describe( "server_brand" ))
     location          : str = Field( title = "Server URL", description = describe( "location_fuseki" ))
     repository        : str= Field( pattern = r"^\w{1,32}$", title = "Repository ID", description = describe( "repository" ))
-    file_server_port  : Optional[ int ]  = Field( 0, title = "file_server_port", description = describe( "file_server_port" ))
+    # file_server_port  : Optional[ int ]  = Field( 0, title = "file_server_port", description = describe( "file_server_port" ))
 
 class RDF4JConf( BaseModel ):
     model_config = ConfigDict( extra='allow' )
     brand             : Literal[ "rdf4j" ] = Field( title = "RDF4J brand", description = describe(  "server_brand" ))
     location          : str = Field( title = "Server URL", description = describe( "location_rdf4j" ))
     repository        : str= Field( pattern = r"^\w{1,32}$", title = "Repository ID", description = describe( "repository" ))
-    file_server_port  : Optional[ int ]  = Field( 0, title = "file_server_port", description = describe( "file_server_port" ))
+    # file_server_port  : Optional[ int ]  = Field( 0, title = "file_server_port", description = describe( "file_server_port" ))
+
+class QleverConf( BaseModel ): # Nota Bene: qlever is currently read-only,  access_token, file_server_port are useless
+    model_config = ConfigDict( extra='allow' )
+    brand             : Literal[ "qlever" ] = Field( title = "Qlever brand", description = describe(  "server_brand" ))
+    location          : str = Field( title = "Server URL", description = describe( "location_qlever" ))
+    repository        : str= Field( pattern = r"^\w{1,32}$", title = "Repository ID", description = describe( "repository" ))
+    # access_token      : str = Field( title = "Qlever access token", description = "Qlever access token is mandatory to write the repsoitory" )
+    # file_server_port  : Optional[ int ]  = Field( 0, title = "file_server_port", description = describe( "file_server_port" ))
 
 class SpecialEnum( str, Enum ):
     sib_swiss_void   = 'sib_swiss_void'
@@ -224,7 +235,7 @@ class QueryConf( BaseModel ):
 class KGStewardConf( BaseModel ):
     model_config = ConfigDict( extra='allow' )
     version           : Literal[ "kgsteward_yaml_3" ] = Field( title = "YAML syntax version", description = "This mandatory fixed value determines the admissible YAML syntax" )
-    server            : Union[ GraphDBConf, RDF4JConf, FusekiConf ] = Field( discriminator = 'brand' )
+    server            : Union[ GraphDBConf, RDF4JConf, FusekiConf, QleverConf ] = Field( discriminator = 'brand' )
     file_loader       : Union[ SparqlFileLoader, StoreFileLoader, HttpServerFileLoader, RiotChunkStoreFileLoader ]
     url_loader        : Union[ SparqlUrlLoader, CurlRiotChunkStoreUrlLoader ]
     dataset           : List[ DatasetConf ] = Field( title = "Knowledge Graph content", description = describe( "dataset" ))
